module.exports = defineTest({
	description: 'handles member expressions in patterns (#2750)'
});
